permission package
==================

Subpackages
-----------

.. toctree::

    permission.decorators
    permission.logics
    permission.templatetags
    permission.tests
    permission.utils

Submodules
----------

permission.backends module
--------------------------

.. automodule:: permission.backends
    :members:
    :undoc-members:
    :show-inheritance:

permission.conf module
----------------------

.. automodule:: permission.conf
    :members:
    :undoc-members:
    :show-inheritance:

permission.handlers module
--------------------------

.. automodule:: permission.handlers
    :members:
    :undoc-members:
    :show-inheritance:

permission.models module
------------------------

.. automodule:: permission.models
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission
    :members:
    :undoc-members:
    :show-inheritance:
